Module boost_units

Module boost_units 

Constants

BOOST_KICKOFF_START_AMOUNT
The raw replay boost amount players spawn with at each standard kickoff.
BOOST_MAX_AMOUNT
The maximum raw boost value stored in replay data.
BOOST_USED_PERCENT_PER_SECOND
The rate at which boost drains while active, in percentage points per second.
BOOST_USED_PER_SECONDDeprecated
BOOST_USED_RAW_UNITS_PER_SECOND
The rate at which boost drains while active, in raw replay units per second.

Functions

boost_amount_to_percent
Converts a raw replay boost amount (0..=255) to a percentage (0..=100).
boost_percent_to_amount
Converts a boost percentage (0..=100) to a raw replay boost amount (0..=255).