Module error

Module error 

Crate-wide error type and result alias.

Most fallible operations return SubtrActorResult, whose error is SubtrActorError (a SubtrActorErrorVariant plus a captured backtrace).

Structs

SubtrActorError
SubtrActorError struct provides an error variant SubtrActorErrorVariant along with its backtrace.

Enums

SubtrActorErrorVariant
SubtrActorErrorVariant is an enumeration of all the specific error variants that can occur while processing game replays in the subtr-actor domain. These include errors related to network frames, frame indexing, player sets, actor states, object ids, team identities, and data types amongst others.

Type Aliases

SubtrActorResult