macro_rules! build_player_feature_adder {
($struct_name:ident, $prop_getter:expr_2021, $( $column_names:expr_2021 ),* $(,)?) => { ... };
}Expand description
Declares a new per-player feature-adder type and wires it into the ndarray traits.
macro_rules! build_player_feature_adder {
($struct_name:ident, $prop_getter:expr_2021, $( $column_names:expr_2021 ),* $(,)?) => { ... };
}Declares a new per-player feature-adder type and wires it into the ndarray traits.