macro_rules! get_attribute_errors_expected {
($self:ident, $map:expr, $prop:expr, $type:path) => { ... };
}Expand description
Obtains an attribute from a map and ensures it matches the expected type.
Arguments
$self- The struct or instance on which the function is invoked.$map- The data map.$prop- The attribute key.$type- The expected enum path.