pub struct ActorState {
pub attributes: HashMap<ObjectId, (Attribute, usize)>,
pub derived_attributes: HashMap<String, (Attribute, usize)>,
pub object_id: ObjectId,
pub name_id: Option<i32>,
}Expand description
A struct representing the state of an actor.
This includes both attributes and derived attributes, along with the associated object id and name id.
Fields
attributes: HashMap<ObjectId, (Attribute, usize)>A map of the actor’s attributes with their corresponding object ids and frame indices.
derived_attributes: HashMap<String, (Attribute, usize)>A map of the actor’s derived attributes with their corresponding object ids and frame indices.
object_id: ObjectIdThe object id associated with the actor.
name_id: Option<i32>Optional name id associated with the actor.