Module search

Module search 

Enums

SearchDirection
Enum to define the direction of searching within a collection.

Functions

find_in_direction
Searches for an item in a slice in a specified direction and returns the first item that matches the provided predicate.