pub struct KickoffPlayerStats {Show 13 fields
pub count: u32,
pub touches: u32,
pub fakes: u32,
pub misses: u32,
pub support_go_for_boosts: u32,
pub support_cheats: u32,
pub support_other: u32,
pub support_distance_sample_count: u32,
pub cumulative_support_distance_from_center: f32,
pub kickoff_goal_count: u32,
pub boost_after_sample_count: u32,
pub cumulative_boost_after: f32,
pub labeled_event_counts: LabeledCounts,
}Expand description
Per-player accumulated kickoff stats.
Fields
count: u32touches: u32fakes: u32misses: u32support_go_for_boosts: u32support_cheats: u32support_other: u32support_distance_sample_count: u32Kickoffs on which this player was a non-taker (support) and contributed
a start_distance_from_center sample.
cumulative_support_distance_from_center: f32Sum of support spawn distances from field center, for averaging.
kickoff_goal_count: u32boost_after_sample_count: u32cumulative_boost_after: f32labeled_event_counts: LabeledCountsImplementations
Sourceimpl KickoffPlayerStats
impl KickoffPlayerStats
pub fn average_boost_after(&self) -> f32
Sourcepub fn average_support_distance_from_center(&self) -> f32
pub fn average_support_distance_from_center(&self) -> f32
Mean spawn distance from field center across kickoffs on which this player was support.