pub enum FlickKind {
Other,
Forward,
Reverse,
Side,
}Expand description
The kind of flick detected, from the dodge direction (see
[REVERSE_FLICK_MIN_BACKWARD]).
Variants
Other
No clear dodge direction (e.g. missing dodge torque), or a dodge that is neither clearly forward, backward, nor sideways.
Forward
A front-flip flick: the dodge is forward.
Reverse
A reverse flick: the dodge is a backflip.
Side
A side flick: the dodge is dominated by its sideways component.
Implementations