pub enum WallAerialWall {
Left,
Right,
Front,
Back,
FrontLeft,
FrontRight,
BackLeft,
BackRight,
}Expand description
Which wall a player took off from, relative to their attack direction.
Front/Back are the end walls (the opponent’s net side vs. the player’s
own net side); Left/Right are the side walls; the *Left/*Right
variants are the rounded corners where a side wall meets an end wall.
Variants
Implementations
Sourceimpl WallAerialWall
impl WallAerialWall
pub fn as_label_value(self) -> &'static str