pub struct PositioningEvent {Show 29 fields
pub time: f32,
pub frame: usize,
pub player: PlayerId,
pub is_team_0: bool,
pub active_game_time: f32,
pub tracked_time: f32,
pub sum_distance_to_teammates: f32,
pub sum_distance_to_ball: f32,
pub sum_distance_to_ball_has_possession: f32,
pub time_has_possession: f32,
pub sum_distance_to_ball_no_possession: f32,
pub time_no_possession: f32,
pub time_demolished: f32,
pub time_no_teammates: f32,
pub time_most_back: f32,
pub time_most_forward: f32,
pub time_mid_role: f32,
pub time_other_role: f32,
pub time_defensive_zone: f32,
pub time_neutral_zone: f32,
pub time_offensive_zone: f32,
pub time_defensive_half: f32,
pub time_offensive_half: f32,
pub time_closest_to_ball: f32,
pub time_farthest_from_ball: f32,
pub time_behind_ball: f32,
pub time_level_with_ball: f32,
pub time_in_front_of_ball: f32,
pub times_caught_ahead_of_play_on_conceded_goals: u32,
}Fields
time: f32frame: usizeplayer: PlayerIdis_team_0: boolactive_game_time: f32tracked_time: f32sum_distance_to_teammates: f32sum_distance_to_ball: f32sum_distance_to_ball_has_possession: f32time_has_possession: f32sum_distance_to_ball_no_possession: f32time_no_possession: f32time_demolished: f32time_no_teammates: f32time_most_back: f32time_most_forward: f32time_mid_role: f32time_other_role: f32time_defensive_zone: f32time_neutral_zone: f32time_offensive_zone: f32time_defensive_half: f32time_offensive_half: f32time_closest_to_ball: f32time_farthest_from_ball: f32time_behind_ball: f32time_level_with_ball: f32time_in_front_of_ball: f32times_caught_ahead_of_play_on_conceded_goals: u32Trait Implementations
Sourceimpl Clone for PositioningEvent
impl Clone for PositioningEvent
Sourcefn clone(&self) -> PositioningEvent
fn clone(&self) -> PositioningEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PositioningEvent
impl Debug for PositioningEvent
Sourceimpl PartialEq for PositioningEvent
impl PartialEq for PositioningEvent
Sourcefn eq(&self, other: &PositioningEvent) -> bool
fn eq(&self, other: &PositioningEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PositioningEvent
impl Serialize for PositioningEvent
Sourceimpl TS for PositioningEvent
impl TS for PositioningEvent
Sourcetype WithoutGenerics = PositioningEvent
type WithoutGenerics = PositioningEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = PositioningEvent
type OptionInnerType = PositioningEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,
impl StructuralPartialEq for PositioningEvent