pub struct BallHalfCalculator { /* private fields */ }Expand description
Tracks which half of the field the ball is in over time.
Implementations
Sourceimpl BallHalfCalculator
impl BallHalfCalculator
pub fn new() -> Self
pub fn with_config(config: BallHalfCalculatorConfig) -> Self
pub fn events(&self) -> &[BallHalfEvent]
pub fn new_events(&self) -> &[BallHalfEvent]
pub fn projected_events(&self) -> Vec<BallHalfEvent>
pub fn flush_pending_event(&mut self)
Sourcepub fn current_event(&self) -> Option<&BallHalfEvent>
pub fn current_event(&self) -> Option<&BallHalfEvent>
The event covering the most recently processed frame (in-progress pending span, or the last committed event once flushed).
pub fn config(&self) -> &BallHalfCalculatorConfig
pub fn update( &mut self, frame: &FrameInfo, ball: &BallFrameState, live_play_state: &LivePlayState, ) -> SubtrActorResult<()>