pub struct BallThirdCalculator { /* private fields */ }Implementations
Sourceimpl BallThirdCalculator
impl BallThirdCalculator
pub fn new() -> Self
pub fn with_config(config: BallThirdCalculatorConfig) -> Self
pub fn events(&self) -> &[BallThirdEvent]
pub fn new_events(&self) -> &[BallThirdEvent]
pub fn projected_events(&self) -> Vec<BallThirdEvent>
pub fn flush_pending_event(&mut self)
Sourcepub fn current_event(&self) -> Option<&BallThirdEvent>
pub fn current_event(&self) -> Option<&BallThirdEvent>
The event covering the most recently processed frame (in-progress pending span, or the last committed event once flushed).
pub fn config(&self) -> &BallThirdCalculatorConfig
pub fn update( &mut self, frame: &FrameInfo, ball: &BallFrameState, live_play_state: &LivePlayState, ) -> SubtrActorResult<()>