pub struct BoostPickupEvent {Show 15 fields
pub frame: usize,
pub time: f32,
pub player_id: PlayerId,
pub player_position: Option<[f32; 3]>,
pub is_team_0: bool,
pub pad_type: BoostPickupPadType,
pub field_half: BoostPickupFieldHalf,
pub activity: BoostPickupActivity,
pub detection: BoostPickupDetection,
pub pad_zone: Option<BoostPickupPadZone>,
pub is_steal: bool,
pub collected_amount: f32,
pub overfill_amount: f32,
pub boost_before: Option<f32>,
pub boost_after: Option<f32>,
}Expand description
A single boost pickup. Replaces the former pickup-comparison + ledger Collected/Stolen/ Overfill events: pad classification, theft, and amounts are all facets of one pickup.
Fields
frame: usizetime: f32player_id: PlayerIdplayer_position: Option<[f32; 3]>is_team_0: boolpad_type: BoostPickupPadTypefield_half: BoostPickupFieldHalfactivity: BoostPickupActivitydetection: BoostPickupDetectionpad_zone: Option<BoostPickupPadZone>Oriented pad location bucket. Big pads use offensive/neutral/defensive; small pads use offensive/defensive half.
is_steal: boolA steal is a pickup collected on the opponent’s half (mirrors the former Stolen ledger
transaction condition).
collected_amount: f32Boost actually gained from this pickup.
overfill_amount: f32Boost lost to the cap because the player was already near full when collecting.
boost_before: Option<f32>boost_after: Option<f32>Trait Implementations
Sourceimpl Clone for BoostPickupEvent
impl Clone for BoostPickupEvent
Sourceimpl Debug for BoostPickupEvent
impl Debug for BoostPickupEvent
Sourceimpl PartialEq for BoostPickupEvent
impl PartialEq for BoostPickupEvent
Sourceimpl Serialize for BoostPickupEvent
impl Serialize for BoostPickupEvent
Sourceimpl StatsEvent for BoostPickupEvent
impl StatsEvent for BoostPickupEvent
const DEFINITION: EventDefinition = BOOST_PICKUP_EVENT_DEFINITION
impl StructuralPartialEq for BoostPickupEvent
Sourceimpl TS for BoostPickupEvent
impl TS for BoostPickupEvent
Sourcetype WithoutGenerics = BoostPickupEvent
type WithoutGenerics = BoostPickupEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = BoostPickupEvent
type OptionInnerType = BoostPickupEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,