pub struct CeilingShotEvent {Show 16 fields
pub time: f32,
pub frame: usize,
pub player: PlayerId,
pub is_team_0: bool,
pub ceiling_contact_time: f32,
pub ceiling_contact_frame: usize,
pub time_since_ceiling_contact: f32,
pub ceiling_contact_position: [f32; 3],
pub touch_position: [f32; 3],
pub local_ball_position: [f32; 3],
pub separation_from_ceiling: f32,
pub roof_alignment: f32,
pub forward_alignment: f32,
pub forward_approach_speed: f32,
pub ball_speed_change: f32,
pub confidence: f32,
}Fields
time: f32frame: usizeplayer: PlayerIdis_team_0: boolceiling_contact_time: f32ceiling_contact_frame: usizetime_since_ceiling_contact: f32ceiling_contact_position: [f32; 3]touch_position: [f32; 3]local_ball_position: [f32; 3]separation_from_ceiling: f32roof_alignment: f32forward_alignment: f32forward_approach_speed: f32ball_speed_change: f32confidence: f32Trait Implementations
Sourceimpl Clone for CeilingShotEvent
impl Clone for CeilingShotEvent
Sourcefn clone(&self) -> CeilingShotEvent
fn clone(&self) -> CeilingShotEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CeilingShotEvent
impl Debug for CeilingShotEvent
Sourceimpl PartialEq for CeilingShotEvent
impl PartialEq for CeilingShotEvent
Sourceimpl Serialize for CeilingShotEvent
impl Serialize for CeilingShotEvent
Sourceimpl TS for CeilingShotEvent
impl TS for CeilingShotEvent
Sourcetype WithoutGenerics = CeilingShotEvent
type WithoutGenerics = CeilingShotEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = CeilingShotEvent
type OptionInnerType = CeilingShotEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,
impl StructuralPartialEq for CeilingShotEvent