pub struct CorePlayerGoalContextEvent {Show 18 fields
pub time: f32,
pub frame: usize,
pub player: PlayerId,
pub player_position: Option<[f32; 3]>,
pub is_team_0: bool,
pub scoring_team_is_team_0: bool,
pub goals_conceded_while_last_defender: bool,
pub goals_for_while_most_back: bool,
pub goals_against_while_most_back: bool,
pub caught_ahead_of_play_on_conceded_goal: bool,
pub goal_against_boost_amount: Option<f32>,
pub goal_against_average_boost_in_leadup: Option<f32>,
pub goal_against_min_boost_in_leadup: Option<f32>,
pub goal_against_position: Option<GoalContextPosition>,
pub scoring_goal_last_touch_position: Option<GoalContextPosition>,
pub time_after_kickoff: Option<f32>,
pub goal_buildup: Option<GoalBuildupKind>,
pub ball_air_time_before_goal: Option<f32>,
}Expand description
Per-player context attached to a goal.
Fields
time: f32frame: usizeplayer: PlayerIdplayer_position: Option<[f32; 3]>is_team_0: boolscoring_team_is_team_0: boolgoals_conceded_while_last_defender: boolgoals_for_while_most_back: boolgoals_against_while_most_back: boolcaught_ahead_of_play_on_conceded_goal: boolgoal_against_boost_amount: Option<f32>goal_against_average_boost_in_leadup: Option<f32>goal_against_min_boost_in_leadup: Option<f32>goal_against_position: Option<GoalContextPosition>scoring_goal_last_touch_position: Option<GoalContextPosition>time_after_kickoff: Option<f32>goal_buildup: Option<GoalBuildupKind>ball_air_time_before_goal: Option<f32>Trait Implementations
Sourceimpl Clone for CorePlayerGoalContextEvent
impl Clone for CorePlayerGoalContextEvent
Sourceimpl Debug for CorePlayerGoalContextEvent
impl Debug for CorePlayerGoalContextEvent
impl StructuralPartialEq for CorePlayerGoalContextEvent
Sourceimpl TS for CorePlayerGoalContextEvent
impl TS for CorePlayerGoalContextEvent
Sourcetype WithoutGenerics = CorePlayerGoalContextEvent
type WithoutGenerics = CorePlayerGoalContextEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = CorePlayerGoalContextEvent
type OptionInnerType = CorePlayerGoalContextEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,