pub struct DemolitionEvent {
pub time: f32,
pub frame: usize,
pub attacker: PlayerId,
pub victim: PlayerId,
pub attacker_is_team_0: Option<bool>,
pub victim_is_team_0: Option<bool>,
pub attacker_position: Option<[f32; 3]>,
pub victim_position: Option<[f32; 3]>,
}Expand description
A single demolition, linking the demoer (attacker) to the demoee
(victim). Each demolition emits exactly one of these events; the attacker
side contributes a demo inflicted and the victim side a demo taken.
Fields
time: f32frame: usizeattacker: PlayerIdvictim: PlayerIdattacker_is_team_0: Option<bool>victim_is_team_0: Option<bool>attacker_position: Option<[f32; 3]>victim_position: Option<[f32; 3]>Trait Implementations
Sourceimpl Clone for DemolitionEvent
impl Clone for DemolitionEvent
Sourceimpl Debug for DemolitionEvent
impl Debug for DemolitionEvent
Sourceimpl PartialEq for DemolitionEvent
impl PartialEq for DemolitionEvent
Sourceimpl Serialize for DemolitionEvent
impl Serialize for DemolitionEvent
Sourceimpl StatsEvent for DemolitionEvent
impl StatsEvent for DemolitionEvent
const DEFINITION: EventDefinition = DEMOLITION_EVENT_DEFINITION
impl StructuralPartialEq for DemolitionEvent
Sourceimpl TS for DemolitionEvent
impl TS for DemolitionEvent
Sourcetype WithoutGenerics = DemolitionEvent
type WithoutGenerics = DemolitionEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = DemolitionEvent
type OptionInnerType = DemolitionEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,