pub struct DodgeImpulse {Show 18 fields
pub start_position: [f32; 3],
pub end_position: [f32; 3],
pub start_speed: f32,
pub end_speed: f32,
pub raw_velocity_delta: [f32; 3],
pub estimated_impulse_delta: [f32; 3],
pub estimated_direction: [f32; 3],
pub estimated_horizontal_direction: [f32; 2],
pub estimated_impulse_magnitude: f32,
pub estimated_horizontal_impulse_magnitude: f32,
pub local_forward_component: f32,
pub local_right_component: f32,
pub local_up_component: f32,
pub direction_label: String,
pub boost_sample_count: u32,
pub sample_count: u32,
pub boost_compensation_magnitude: f32,
pub confidence: f32,
}Expand description
An estimated dodge impulse derived from a measurable velocity change.
Fields
start_position: [f32; 3]end_position: [f32; 3]start_speed: f32end_speed: f32raw_velocity_delta: [f32; 3]estimated_impulse_delta: [f32; 3]estimated_direction: [f32; 3]estimated_horizontal_direction: [f32; 2]estimated_impulse_magnitude: f32estimated_horizontal_impulse_magnitude: f32local_forward_component: f32local_right_component: f32local_up_component: f32direction_label: Stringboost_sample_count: u32sample_count: u32boost_compensation_magnitude: f32confidence: f32Trait Implementations
Sourceimpl Clone for DodgeImpulse
impl Clone for DodgeImpulse
Sourceimpl Debug for DodgeImpulse
impl Debug for DodgeImpulse
Sourceimpl PartialEq for DodgeImpulse
impl PartialEq for DodgeImpulse
Sourceimpl Serialize for DodgeImpulse
impl Serialize for DodgeImpulse
impl StructuralPartialEq for DodgeImpulse
Sourceimpl TS for DodgeImpulse
impl TS for DodgeImpulse
Sourcetype WithoutGenerics = DodgeImpulse
type WithoutGenerics = DodgeImpulse
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = DodgeImpulse
type OptionInnerType = DodgeImpulse
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,