pub struct KickoffSupportEvent {
pub player: PlayerId,
pub is_team_0: bool,
pub start_position: [f32; 3],
pub start_distance_from_center: f32,
pub spawn_position: KickoffSpawnPosition,
pub start_boost: Option<f32>,
pub boost_after: Option<f32>,
pub first_touch_time: Option<f32>,
pub first_touch_frame: Option<usize>,
pub support_behavior: KickoffSupportBehavior,
}Expand description
Kickoff event for a supporting player.
Fields
player: PlayerIdis_team_0: boolstart_position: [f32; 3]start_distance_from_center: f32Horizontal distance (uu) of the support player’s spawn from field
center — i.e. from the ball’s kickoff position at the origin. Larger
values mean the player started further back/wider; a cheat support
closes this gap as the kickoff develops while a back-positioned support
keeps it.
spawn_position: KickoffSpawnPositionstart_boost: Option<f32>boost_after: Option<f32>first_touch_time: Option<f32>first_touch_frame: Option<usize>support_behavior: KickoffSupportBehaviorTrait Implementations
Sourceimpl Clone for KickoffSupportEvent
impl Clone for KickoffSupportEvent
Sourceimpl Debug for KickoffSupportEvent
impl Debug for KickoffSupportEvent
Sourceimpl PartialEq for KickoffSupportEvent
impl PartialEq for KickoffSupportEvent
Sourceimpl Serialize for KickoffSupportEvent
impl Serialize for KickoffSupportEvent
impl StructuralPartialEq for KickoffSupportEvent
Sourceimpl TS for KickoffSupportEvent
impl TS for KickoffSupportEvent
Sourcetype WithoutGenerics = KickoffSupportEvent
type WithoutGenerics = KickoffSupportEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = KickoffSupportEvent
type OptionInnerType = KickoffSupportEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,