pub struct SpeedFlipEvent {Show 24 fields
pub time: f32,
pub frame: usize,
pub resolved_time: f32,
pub resolved_frame: usize,
pub player: PlayerId,
pub is_team_0: bool,
pub time_since_kickoff_start: f32,
pub start_position: [f32; 3],
pub end_position: [f32; 3],
pub start_speed: f32,
pub max_speed: f32,
pub best_alignment: f32,
pub initial_boost_alignment: f32,
pub best_boost_alignment: f32,
pub boost_alignment_sample_count: u32,
pub dodge_delay_after_ground_leave_seconds: f32,
pub diagonal_score: f32,
pub estimated_dodge_impulse_magnitude: f32,
pub estimated_dodge_impulse_forward_component: f32,
pub estimated_dodge_impulse_side_component: f32,
pub estimated_dodge_impulse_up_component: f32,
pub cancel_score: f32,
pub speed_score: f32,
pub confidence: f32,
}Expand description
A ground-started diagonal dodge/cancel acceleration pattern, primarily for kickoff speed flips.
Fields
time: f32frame: usizeresolved_time: f32resolved_frame: usizeplayer: PlayerIdis_team_0: booltime_since_kickoff_start: f32start_position: [f32; 3]end_position: [f32; 3]start_speed: f32max_speed: f32best_alignment: f32initial_boost_alignment: f32best_boost_alignment: f32boost_alignment_sample_count: u32dodge_delay_after_ground_leave_seconds: f32diagonal_score: f32estimated_dodge_impulse_magnitude: f32estimated_dodge_impulse_forward_component: f32estimated_dodge_impulse_side_component: f32estimated_dodge_impulse_up_component: f32cancel_score: f32speed_score: f32confidence: f32Trait Implementations
Sourceimpl Clone for SpeedFlipEvent
impl Clone for SpeedFlipEvent
Sourceimpl Debug for SpeedFlipEvent
impl Debug for SpeedFlipEvent
Sourceimpl PartialEq for SpeedFlipEvent
impl PartialEq for SpeedFlipEvent
Sourceimpl Serialize for SpeedFlipEvent
impl Serialize for SpeedFlipEvent
Sourceimpl StatsEvent for SpeedFlipEvent
impl StatsEvent for SpeedFlipEvent
const DEFINITION: EventDefinition = SPEED_FLIP_EVENT_DEFINITION
impl StructuralPartialEq for SpeedFlipEvent
Sourceimpl TS for SpeedFlipEvent
impl TS for SpeedFlipEvent
Sourcetype WithoutGenerics = SpeedFlipEvent
type WithoutGenerics = SpeedFlipEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = SpeedFlipEvent
type OptionInnerType = SpeedFlipEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,