macro_rules! attribute_match {
($value:expr, $type:path $(,)?) => { ... };
}Expand description
Attempts to match an attribute value with the given type.
Arguments
$value- An expression that yields the attribute value.$type- The expected enum path.
If the attribute matches the specified type, it is returned wrapped in an
Ok variant of a Result. If the attribute doesn’t match, it results in an
Err variant with a SubtrActorError, specifying the expected type and
the actual type.