macro_rules! build_player_feature_adder {
($struct_name:ident, $prop_getter:expr, $( $column_names:expr ),* $(,)?) => { ... };
}Expand description
Declares a new per-player feature-adder type and wires it into the ndarray traits.
macro_rules! build_player_feature_adder {
($struct_name:ident, $prop_getter:expr, $( $column_names:expr ),* $(,)?) => { ... };
}Declares a new per-player feature-adder type and wires it into the ndarray traits.