Module processor

Module processor 

Re-exports

pub use actor_state::*;

Modules

actor_state

Structs

ReplayProcessor
The ReplayProcessor struct is a pivotal component in subtr-actor’s replay parsing pipeline. It is designed to process and traverse an actor graph of a Rocket League replay, and expose methods for collectors to gather specific data points as it progresses through the replay.