Module search
subtr_
actor
0.5.0
Module search
Module Items
Enums
Functions
In crate subtr_
actor
subtr_actor
Module
search
Enums

Search
Direction
Enum to define the direction of searching within a collection.
Functions

find_
in_
direction
Searches for an item in a slice in a specified direction and returns the first item that matches the provided predicate.