pub struct FlickEvent {Show 20 fields
pub time: f32,
pub frame: usize,
pub sample_time: f32,
pub sample_frame: usize,
pub player: PlayerId,
pub is_team_0: bool,
pub dodge_time: f32,
pub dodge_frame: usize,
pub time_since_dodge: f32,
pub setup_start_time: f32,
pub setup_start_frame: usize,
pub setup_duration: f32,
pub setup_touch_count: u32,
pub average_horizontal_gap: f32,
pub average_vertical_gap: f32,
pub ball_speed_change: f32,
pub ball_impulse: [f32; 3],
pub impulse_away_alignment: f32,
pub vertical_impulse: f32,
pub confidence: f32,
}Fields
time: f32frame: usizesample_time: f32sample_frame: usizeplayer: PlayerIdis_team_0: booldodge_time: f32dodge_frame: usizetime_since_dodge: f32setup_start_time: f32setup_start_frame: usizesetup_duration: f32setup_touch_count: u32average_horizontal_gap: f32average_vertical_gap: f32ball_speed_change: f32ball_impulse: [f32; 3]impulse_away_alignment: f32vertical_impulse: f32confidence: f32Trait Implementations
Sourceimpl Clone for FlickEvent
impl Clone for FlickEvent
Sourcefn clone(&self) -> FlickEvent
fn clone(&self) -> FlickEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlickEvent
impl Debug for FlickEvent
Sourceimpl PartialEq for FlickEvent
impl PartialEq for FlickEvent
Sourcefn eq(&self, other: &FlickEvent) -> bool
fn eq(&self, other: &FlickEvent) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FlickEvent
impl Serialize for FlickEvent
Sourceimpl TS for FlickEvent
impl TS for FlickEvent
Sourcetype WithoutGenerics = FlickEvent
type WithoutGenerics = FlickEvent
If this type does not have generic parameters, then
WithoutGenerics should just be Self.
If the type does have generic parameters, then all generic parameters must be replaced with
a dummy type, e.g ts_rs::Dummy or ().
The only requirement for these dummy types is that EXPORT_TO must be None. Read moreSourcetype OptionInnerType = FlickEvent
type OptionInnerType = FlickEvent
If the implementing type is
std::option::Option<T>, then this associated type is set to T.
All other implementations of TS should set this type to Self instead.Sourcefn decl_concrete() -> String
fn decl_concrete() -> String
Declaration of this type using the supplied generic arguments.
The resulting TypeScript definition will not be generic. For that, see
TS::decl().
If this type is not generic, then this function is equivalent to TS::decl().Sourcefn decl() -> String
fn decl() -> String
Declaration of this type, e.g.
type User = { user_id: number, ... }.
This function will panic if the type has no declaration. Read moreSourcefn inline() -> String
fn inline() -> String
Formats this types definition in TypeScript, e.g
{ user_id: number }.
This function will panic if the type cannot be inlined.Sourcefn inline_flattened() -> String
fn inline_flattened() -> String
Flatten a type declaration.
This function will panic if the type cannot be flattened.
This function will panic if the type cannot be flattened.
Sourcefn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_generics(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all type parameters of this type.
Sourcefn output_path() -> Option<PathBuf>
fn output_path() -> Option<PathBuf>
Returns the output path to where
The returned path does not include the base directory from
T should be exported.The returned path does not include the base directory from
TS_RS_EXPORT_DIR. Read moreSourcefn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
fn visit_dependencies(v: &mut impl TypeVisitor)where
Self: 'static,
Iterates over all dependency of this type.
Sourcefn docs() -> Option<String>
fn docs() -> Option<String>
JSDoc comment to describe this type in TypeScript - when
TS is derived, docs are
automatically read from your doc comments or #[doc = ".."] attributesSourcefn dependencies() -> Vec<Dependency>where
Self: 'static,
fn dependencies() -> Vec<Dependency>where
Self: 'static,
Resolves all dependencies of this type recursively.
Sourcefn export() -> Result<(), ExportError>where
Self: 'static,
fn export() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem.
To export this type together with all of its dependencies, use
TS::export_all. Read moreSourcefn export_all() -> Result<(), ExportError>where
Self: 'static,
fn export_all() -> Result<(), ExportError>where
Self: 'static,
Manually export this type to the filesystem, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
fn export_all_to(out_dir: impl AsRef<Path>) -> Result<(), ExportError>where
Self: 'static,
Manually export this type into the given directory, together with all of its dependencies.
To export only this type, without its dependencies, use
To export only this type, without its dependencies, use
TS::export. Read moreSourcefn export_to_string() -> Result<String, ExportError>where
Self: 'static,
fn export_to_string() -> Result<String, ExportError>where
Self: 'static,
impl StructuralPartialEq for FlickEvent