Module util

Module util 

Structs

DemolishInfo
DemolishInfo struct represents data related to a demolition event in the game.
PlayerInfo
PlayerInfo struct provides detailed information about a specific player in the replay.
ReplayMeta
ReplayMeta struct represents metadata about the replay being processed.

Enums

DemolishAttribute
Wrapper enum for different demolition attribute formats across Rocket League versions.
DemolishFormat
Represents which demolition format a replay uses.
SearchDirection
Enum to define the direction of searching within a collection.

Functions

apply_velocities_to_rigid_body
find_in_direction
Searches for an item in a slice in a specified direction and returns the first item that matches the provided predicate.
find_player_stats
get_interpolated_rigid_body
Interpolates between two boxcars::RigidBody states based on the provided time.
glam_to_quat
glam_to_vec
quat_to_glam
vec_to_glam

Type Aliases

PlayerId